==> keycloak-24.0.3.tar.gz: keycloak-24.0.3/quarkus/runtime/src/main/java/org/keycloak/quarkus/runtime/integration/resteasy/QuarkusClientConnection.java <==
/*
 * Copyright 2022 Red Hat, Inc. and/or its affiliates
 * and other contributors as indicated by the @author tags.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.keycloak.quarkus.runtime.integration.resteasy;

import org.keycloak.common.ClientConnection;

import io.vertx.core.http.HttpServerRequest;

public final class QuarkusClientConnection implements ClientConnection {

    private final HttpServerRequest request;

    public QuarkusClientConnection(HttpServerRequest request) {
        this.request = request;
    }

    @Override
    public String getRemoteAddr() {
        return request.remoteAddress().host();
    }

    @Override
    public String getRemoteHost() {
        return request.remoteAddress().host();
    }

    @Override
    public int getRemotePort() {
        return request.remoteAddress().port();
    }

    @Override
    public String getLocalAddr() {
        return request.localAddress().host();
    }

    @Override
    public int getLocalPort() {
        return request.localAddress().port();
    }
}

==> keycloak-26.1.1.tar.gz: keycloak-26.1.1/quarkus/runtime/src/main/java/org/keycloak/quarkus/runtime/integration/resteasy/QuarkusClientConnection.java <==
/*
 * Copyright 2022 Red Hat, Inc. and/or its affiliates
 * and other contributors as indicated by the @author tags.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.keycloak.quarkus.runtime.integration.resteasy;

import org.keycloak.common.ClientConnection;

import io.vertx.core.http.HttpServerRequest;

public final class QuarkusClientConnection implements ClientConnection {

    private final HttpServerRequest request;

    public QuarkusClientConnection(HttpServerRequest request) {
        this.request = request;
    }

    @Override
    public String getRemoteAddr() {
        return request.remoteAddress().hostAddress();
    }

    @Override
    public String getRemoteHost() {
        return request.remoteAddress().host();
    }

    @Override
    public int getRemotePort() {
        return request.remoteAddress().port();
    }

    @Override
    public String getLocalAddr() {
        return request.localAddress().hostAddress();
    }

    @Override
    public int getLocalPort() {
        return request.localAddress().port();
    }
}
